@@ -5,7 +5,8 @@ context("get_ids")
 test_that("get_ids returns the correct values and classses", {
   skip_on_cran()
 
-  tt <- get_ids(names = "Chironomus riparius", db = "ncbi", messages = FALSE)
+  tt <- get_ids(names = "Chironomus riparius", db = "ncbi",
+    messages = FALSE, suppress = TRUE)
 
   expect_equal(tt[[1]][[1]], "315576")
   expect_is(tt, "ids")
@@ -16,9 +17,10 @@ test_that("get_ids returns the correct values and classses", {
 test_that("get_ids accepts ask and verbose arguments", {
   skip_on_cran()
 
-  expect_message(get_ids(names = "Pinus contorta", db = "ncbi"))
   expect_message(get_ids(names = "Pinus contorta", db = "ncbi",
-    messages = FALSE), NA)
+    suppress = TRUE))
+  expect_message(get_ids(names = "Pinus contorta", db = "ncbi",
+    messages = FALSE, suppress = TRUE), NA)
 })
 
 nn <- c('Imperata brasiliensis','Hylebates cordatus','Apocopis intermedius',
@@ -39,9 +41,9 @@ test_that("works on a variety of names", {
   skip_on_cran()
 
   expect_is(sw(get_ids(nn[13], db = c("ncbi", "itis", "col", "tropicos"),
-    ask = FALSE, messages = FALSE)), "ids")
+    suppress = TRUE, ask = FALSE, messages = FALSE)), "ids")
   expect_is(sw(get_ids(nn[14], db = c("ncbi", "itis", "col", "tropicos"),
-    ask = FALSE, messages = FALSE)), "ids")
+    suppress = TRUE, ask = FALSE, messages = FALSE)), "ids")
   expect_is(sw(get_ids(nn[15], db = c("ncbi", "itis", "col", "tropicos"),
-    ask = FALSE, messages = FALSE)), "ids")
+    suppress = TRUE, ask = FALSE, messages = FALSE)), "ids")
 })
